// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
/**
 * @packageDocumentation
 * @module ui-components-extension
 */
import { FormComponentRegistry, FormWidgetRegistry, IFormComponentRegistry, IFormWidgetRegistry, ILabIconManager } from '@jupyterlab/ui-components';
/**
 * Placeholder for future extension that will provide an icon manager class
 * to assist with overriding/replacing particular sets of icons
 */
const labiconManager = {
    id: '@jupyterlab/ui-components-extension:labicon-manager',
    provides: ILabIconManager,
    autoStart: true,
    activate: (app) => {
        return Object.create(null);
    }
};
/**
 * Sets up the component registry to be used by the FormEditor component.
 */
const registryPlugin = {
    id: '@jupyterlab/settingeditor-extension:form-registry',
    provides: IFormComponentRegistry,
    autoStart: true,
    activate: (app) => {
        const editorRegistry = new FormComponentRegistry();
        return editorRegistry;
    }
};
/**
 * Sets up the widget registry to be used by a RJSF form.
 */
const widgetRegistryPlugin = {
    id: '@jupyterlab/ui-components-extension:widget-registry',
    provides: IFormWidgetRegistry,
    autoStart: true,
    activate: (app) => {
        const formRegistry = new FormWidgetRegistry();
        return formRegistry;
    }
};
export default [labiconManager, registryPlugin, widgetRegistryPlugin];
//# sourceMappingURL=index.js.map